@@ -254,14 +254,14 @@ def worksheet_to_data(ws, locale=None, fs=None, default_cell_border="none"):
 
 
 def render_table(data, append_headers, append_lineno):
-    length = 22
+    length = 18
     n = math.ceil(len(data["rows"]) / length)
     html = []
     rows = []
     for index in range(0, n):
         html.append(
-            ('<div class="item-{}">'
-            '<div class="container">'
+            ('<div class="item-{}"> '
+            '<div class="container"> '
             "<table  "
             'style="border-collapse: collapse" '
             'border="0" '
@@ -286,11 +286,12 @@ def render_table(data, append_headers, append_lineno):
                 rows.append(row)
             for row in data["rows"][index*length:(index+1)*length]:
                 rows.append(row)
-        else :
+        else:
             for row in data["rows"][index:length]:
                 rows.append(row)
         for i, row in enumerate(rows):
-            trow = [('<tr id="{}-of-{}-for-data-{}-of-{}">').format(index, n,index*length,(index+1)*length)]
+            trow = [('<tr id="{}-of-{}-for-data-{}-of-{}">').format(index, n,(index*length)+i,(index+1)*length)]
+            trow.append('\n {}'.format(rows))
             append_lineno(trow, i)
             for cell in row:
                 if cell["column"] in hidden_columns:
@@ -321,9 +322,9 @@ def render_table(data, append_headers, append_lineno):
                 )
             trow.append("</tr>")
             html.append("\n".join(trow))
-        html.append("</table>")
-        html.append("</div>")
-        html.append("</div>")
+        html.append("\n</table>")
+        html.append("\n</div>")
+        html.append("\n</div>")
     return "\n".join(html)
 
 
